==> gtphoto2-framework-0.1.tar.gz: gtphoto2/includes/error_functions.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# This script contains the functions that could be called
# from more than one place, and are used in more
# than one place in the code.

# function: puke
# input: $error: the error message
# return: none
# description: an unrecoverable error has occured, die gracefully
function puke($error) {
	# include the header and sidebar if they haven't been printed
	require_once("includes/header.php");
	require_once("includes/sidebar.php");
	# print the error
?>
<h1>Error!</h1>
<p>An unrecoverable error occured in the page you were trying to view (we're not quite perfect!).  The actual error follows:</p>
<p><?=$error?></p>
<p>The rest of the information is only useful to the developers of GTPhoto.</p>

<?php
	# print useful debugging info
	echo("<h1>Stack Trace</h1><pre>");
	print_r(debug_backtrace());
	echo("</pre>");
	echo("<h1>Get variables</h1><pre>");
	print_r($_GET);
	echo("</pre>");
	echo("<h1>Post variables</h1><pre>");
	print_r($_POST);
	echo("</pre>");
	echo("<h1>Session variables</h1><pre>");
	print_r($_SESSION);
	echo("</pre>");
	# footer
	require_once("includes/footer.php");
	exit();
}

# function: print_errors
# input: none
# return: none
# description: print the errors and warnings generated for a page
function print_errors() {
	
	global $errors;
	global $warnings;

	# print out the errors, all nice and pretty
	if (count($errors) > 0) {
		echo ("<h2>Error!</h2>");
		echo ("<p>The following errors were encountered:</p>\n<p>");
		# print each error in the array on its own line
		echo ("<ul>");
		foreach ($errors as $error) {
			echo ("<li>".$error."</li>");
		}
		echo ("</ul>");
	}
	
	# same thing now with the warnings
	if (count($warnings) > 0) {
		echo ("<h2>Warning!</h2>");
		# print each warning in the array on its own line
		echo ("<ul>");
		foreach ($warnings as $warning) {
			echo ("<li>".$warning."</li>");
		}
		echo ("</ul>");
	}
}

?>

==> gtphoto2-framework-0.2.tar.gz: gtphoto2/includes/error_functions.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# This script contains the functions that could be called
# from more than one place, and are used in more
# than one place in the code.

# function: puke
# input: $error: the error message
# return: none
# description: an unrecoverable error has occured, die gracefully
function puke($error) {
	# include the header and sidebar if they haven't been printed
	require_once("includes/header.php");
	require_once("includes/sidebar.php");
	# print the error
?>
<h1>Error!</h1>
<p>An unrecoverable error occured in the page you were trying to view (we're not quite perfect!).  The actual error follows:</p>
<p><?=$error?></p>
<p>The rest of the information is only useful to developers.</p>

<?php
	# print useful debugging info
	echo("<h1>Stack Trace</h1><pre>");
	print_r(debug_backtrace());
	echo("</pre>");
	echo("<h1>Get variables</h1><pre>");
	print_r($_GET);
	echo("</pre>");
	echo("<h1>Post variables</h1><pre>");
	print_r($_POST);
	echo("</pre>");
	echo("<h1>Session variables</h1><pre>");
	print_r($_SESSION);
	echo("</pre>");
	# footer
	require_once("includes/footer.php");
	exit();
}

# function: print_errors
# input: none
# return: none
# description: print the errors and warnings generated for a page
function print_errors() {
	
	global $errors;
	global $warnings;

	# print out the errors, all nice and pretty
	if (count($errors) > 0) {
		echo ("<h2>Error!</h2>");
		echo ("<p>The following errors were encountered:</p>\n<p>");
		# print each error in the array on its own line
		echo ("<ul>");
		foreach ($errors as $error) {
			echo ("<li>".$error."</li>");
		}
		echo ("</ul>");
	}
	
	# same thing now with the warnings
	if (count($warnings) > 0) {
		echo ("<h2>Warning!</h2>");
		# print each warning in the array on its own line
		echo ("<ul>");
		foreach ($warnings as $warning) {
			echo ("<li>".$warning."</li>");
		}
		echo ("</ul>");
	}
}

?>
